@@ -54,6 +54,7 @@ class ClickReviewLint(ClickReview):
         self.valid_compiled_architectures = ['armhf',
                                              'i386',
                                              'amd64',
+                                             'arm64',
                                              ]
         self.valid_control_architectures = ['all',
                                             'multi',
@@ -348,9 +349,6 @@ exit 1
         # Some checks are already handled in
         # cr_common.py:_verify_manifest_structure()
 
-        # While we support multiple apps in the hooks db, we don't support
-        # multiple apps specifying desktop hooks. Eg, it is ok to specify a
-        # scope, an app and a push-helper, but it isn't ok to specify two apps
         t = 'info'
         n = self._get_check_name('hooks_multiple_apps')
         s = 'OK'
@@ -359,7 +357,9 @@ exit 1
             if "desktop" in self.manifest['hooks'][app]:
                 count += 1
         if count > 1:
-            t = 'error'
+            # 'info' for now but this might be removed in a future version
+            # (see https://launchpad.net/bugs/1496402)
+            t = 'info'
             s = 'more than one desktop app specified in hooks'
         self._add_result(t, n, s)
 
@@ -487,9 +487,50 @@ exit 1
         n = self._get_check_name('external_symlinks')
         s = 'OK'
 
+        common = '(-[0-9.]+)?\.so(\.[0-9.]+)?'
+        libc6_libs = ['ld-*.so',
+                      'libanl',
+                      'libBrokenLocale',
+                      'libc',
+                      'libcidn',
+                      'libcrypt',
+                      'libdl',
+                      'libmemusage',
+                      'libm',
+                      'libnsl',
+                      'libnss_compat',
+                      'libnss_dns',
+                      'libnss_files',
+                      'libnss_hesiod',
+                      'libnss_nisplus',
+                      'libnss_nis',
+                      'libpcprofile',
+                      'libpthread',
+                      'libresolv',
+                      'librt',
+                      'libSegFault',
+                      'libthread_db',
+                      'libutil',
+                      ]
+        libc6_pats = []
+        for lib in libc6_libs:
+            libc6_pats.append(re.compile(r'%s%s' % (lib, common)))
+        libc6_pats.append(re.compile(r'ld-*.so$'))
+        libc6_pats.append(re.compile(r'ld-linux-*.so\.[0-9.]+$'))
+
+        def _in_patterns(pats, f):
+            for pat in pats:
+                if pat.search(f):
+                    return True
+            return False
+
         external_symlinks = list(filter(lambda link: not
                                  os.path.realpath(link).startswith(
-                                     self.unpack_dir), self.pkg_files))
+                                     self.unpack_dir) and
+                                 not _in_patterns(libc6_pats,
+                                                  os.path.basename(link)),
+                                 self.pkg_files))
+
         if external_symlinks:
             t = 'error'
             s = 'package contains external symlinks: %s' % \
@@ -846,6 +887,8 @@ exit 1
                             t = 'error'
                             s = "Hardcoded path '%s' found in '%s'." % (
                                 bad_path, full_fn)
+                except FileNotFoundError:
+                    pass
                 except UnicodeDecodeError:
                     pass
         self._add_result(t, n, s)
@@ -854,23 +897,32 @@ exit 1
         t = 'info'
         n = self._get_check_name('%s_architecture_valid' % test_str)
         s = 'OK'
-        if 'architecture' not in my_dict:
+        if 'architecture' not in my_dict and 'architectures' not in my_dict:
             s = 'OK (architecture not specified)'
             self._add_result(t, n, s)
             return
 
+        key = 'architecture'
+        if self.is_snap and 'architectures' in my_dict:
+            # new yaml allows for 'architecture' and 'architectures'
+            key = 'architectures'
+
         archs_list = list(self.valid_control_architectures)
         archs_list.remove("multi")
 
-        if isinstance(my_dict['architecture'], str) and \
-           my_dict['architecture'] not in archs_list:
+        if self.is_snap and key == 'architectures' and \
+           isinstance(my_dict[key], str):
+            # new yaml uses 'architectures' that must be a list
             t = 'error'
-            s = "not a valid architecture: %s" % my_dict['architecture']
-        elif isinstance(my_dict['architecture'], list):
+            s = "not a valid architecture: %s (not a list)" % my_dict[key]
+        elif isinstance(my_dict[key], str) and my_dict[key] not in archs_list:
+            t = 'error'
+            s = "not a valid architecture: %s" % my_dict[key]
+        elif isinstance(my_dict[key], list):
             if not self.is_snap:
                 archs_list.remove("all")
             bad_archs = []
-            for a in my_dict['architecture']:
+            for a in my_dict[key]:
                 if a not in archs_list:
                     bad_archs.append(a)
                 if len(bad_archs) > 0:
@@ -1011,6 +1063,17 @@ exit 1
 
         self._verify_architecture(self.pkg_yaml, "package yaml")
 
+        t = 'info'
+        n = self._get_check_name('snappy_architecture_deprecated')
+        s = 'OK'
+        l = None
+        if 'architecture' in self.pkg_yaml:
+            t = 'warn'
+            s = "Found deprecated 'architecture' field in " + \
+                "meta/package.yaml. Use 'architectures' instead"
+            l = 'https://developer.ubuntu.com/en/snappy/guides/package-metadata/'
+        self._add_result(t, n, s, link=l)
+
     def check_snappy_unknown_entries(self):
         '''Check for any unknown fields'''
         if not self.is_snap:
