@@ -57,8 +57,9 @@ class TestClickReviewSkeleton(cr_tests.TestClickReview):
         expected = dict()
         expected['info'] = dict()
         expected['warn'] = dict()
-        expected['warn']['skeleton_baz'] = {"text": "TODO",
-                                            "link": "http://example.com"}
+        name = c._get_check_name('baz')
+        expected['warn'][name] = {"text": "TODO",
+                                  "link": "http://example.com"}
         expected['error'] = dict()
         self.check_results(r, expected=expected)
 
